@@ -35,11 +35,12 @@ def load_ALMA_dic(file_path):
 
     try:
                 # Download the file from the URL
-        ALMA_dic = requests.get(url)
+        data  = requests.get(url)
         # Load the data from the file into a Python object
         # data = pickle.loads(response.content)
         # with open(file_path, 'rb') as f:
         #     ALMA_dic = pickle.load(f)
+        ALMA_dic= dict(data)
         return ALMA_dic
     except FileNotFoundError as e:
         print(f"File not found: {file_path}")
